/****************************************************************************/
/* WebWorks Help API                                                        */
/*                                                                          */
/*                                                                          */
/****************************************************************************/

/*$Id: wwhwin.h,v 1.1 2003/09/12 20:25:36 allums Exp $*/


#ifndef WWHELP_WINDOWS_H
#define WWHELP_WINDOWS_H


#include "wwhelp/wwhapi.h"


#ifdef __cplusplus
extern "C"
{
#endif

/****************************************************************************/
/* BSTR WebWorks Help API functions                                         */
/*                                                                          */
/****************************************************************************/

WWHEXPORT int  WWHelp_BSTR_Startup(const BSTR  ParamBaseURL);
WWHEXPORT int  WWHelp_BSTR_Shutdown();

WWHEXPORT int  WWHelp_BSTR_DisplayHelp(const BSTR  ParamContext,
                                       const BSTR  ParamTopic);
WWHEXPORT int  WWHelp_BSTR_DisplayHelpWithNavigation(const BSTR  ParamContext,
                                                     const BSTR  ParamTopic);
WWHEXPORT int  WWHelp_BSTR_DisplayHelpWithContents(const BSTR  ParamContext,
                                                   const BSTR  ParamTopic);
WWHEXPORT int  WWHelp_BSTR_DisplayHelpWithIndex(const BSTR  ParamContext,
                                                const BSTR  ParamTopic);
WWHEXPORT int  WWHelp_BSTR_DisplayHelpWithSearch(const BSTR  ParamContext,
                                                 const BSTR  ParamTopic);
WWHEXPORT int  WWHelp_BSTR_DisplayHelpWithFavorites(const BSTR  ParamContext,
                                                    const BSTR  ParamTopic);
WWHEXPORT int  WWHelp_BSTR_DisplayHelpNavigation();
WWHEXPORT int  WWHelp_BSTR_DisplayHelpContents();
WWHEXPORT int  WWHelp_BSTR_DisplayHelpIndex();
WWHEXPORT int  WWHelp_BSTR_DisplayHelpSearch();
WWHEXPORT int  WWHelp_BSTR_DisplayHelpFavorites();

#ifdef __cplusplus
}
#endif


#endif
